==> gedit-2.19.1.tar.bz2: gedit-2.19.1/gedit/gedit-language-manager.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * gedit-languages-manager.h
 * This file is part of gedit
 *
 * Copyright (C) 2003-2005 - Paolo Maggi 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA.
 */
 
/*
 * Modified by the gedit Team, 2003-2005. See the AUTHORS file for a 
 * list of people on the gedit Team.  
 * See the ChangeLog files for a list of changes. 
 *
 * $Id: gedit-language-manager.h 5646 2007-06-24 19:56:01Z pborelli $
 */

#ifndef __GEDIT_LANGUAGES_MANAGER_H__
#define __GEDIT_LANGUAGES_MANAGER_H__

#include <gtksourceview/gtksourcelanguagemanager.h>

G_BEGIN_DECLS

GtkSourceLanguageManager	*gedit_get_language_manager	(void);

const GSList			*gedit_language_manager_get_available_languages_sorted
								(GtkSourceLanguageManager	*lm);

GtkSourceLanguage		*gedit_language_manager_get_language_from_mime_type 
								(GtkSourceLanguageManager	*lm,
								 const gchar			*mime_type);

G_END_DECLS

#endif /* __GEDIT_LANGUAGES_MANAGER_H__ */

==> gedit-2.19.2.tar.bz2: gedit-2.19.2/gedit/gedit-language-manager.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * gedit-languages-manager.h
 * This file is part of gedit
 *
 * Copyright (C) 2003-2005 - Paolo Maggi 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA.
 */
 
/*
 * Modified by the gedit Team, 2003-2005. See the AUTHORS file for a 
 * list of people on the gedit Team.  
 * See the ChangeLog files for a list of changes. 
 *
 * $Id: gedit-language-manager.h 5659 2007-06-28 08:36:12Z pborelli $
 */

#ifndef __GEDIT_LANGUAGES_MANAGER_H__
#define __GEDIT_LANGUAGES_MANAGER_H__

#include <gtksourceview/gtksourcelanguagemanager.h>

G_BEGIN_DECLS

GtkSourceLanguageManager	*gedit_get_language_manager	(void);

GSList				*gedit_language_manager_list_languages_sorted
								(GtkSourceLanguageManager	*lm);

GtkSourceLanguage		*gedit_language_manager_get_language_from_mime_type 
								(GtkSourceLanguageManager	*lm,
								 const gchar			*mime_type);

G_END_DECLS

#endif /* __GEDIT_LANGUAGES_MANAGER_H__ */
